Step

Struct Step 

pub struct Step<T: Eq + Copy + Hash + Debug + Send + Sync> {
    pub state: T,
    pub transitions: RwLock<HashMap<ToStep<T>, usize>>,
}
A node in the Markov chain, holding a state and weighted transitions to other steps.

Fields

state: T

The state value for this step.

transitions: RwLock<HashMap<ToStep<T>, usize>>

Outgoing transitions and their weights.

Implementations

Source

impl<T> Step<T>
where T: Eq + Copy + Hash + Debug + Send + Sync,

pub fn new(state: T) -> Self

Create a new Step with the given state.

pub fn insert_transition(&self, to_step: ToStep<T>, weight: usize)

Add or update a transition to another step with a given weight.

pub fn next(&self) -> Option<ToStep<T>>

Randomly select the next step based on transition weights.